package geniusweb.party;

import java.util.Set;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility;

import geniusweb.references.ProtocolRef;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * The capabilities of a party
 */
@JsonAutoDetect(fieldVisibility = Visibility.ANY, getterVisibility = Visibility.NONE, setterVisibility = Visibility.NONE)
public class Capabilities {
	/**
	 * List of supported protocols
	 */
	private final Set<ProtocolRef> protocols;

	/**
	 * 
	 * @param protocols the protocols that a Party can handle
	 */
	@JsonCreator
	public Capabilities(@JsonProperty("protocols") Set<ProtocolRef> protocols) {
		if (protocols == null) {
			throw new IllegalArgumentException("protocols==null");
		}
		this.protocols = protocols;
	}

	public Set<ProtocolRef> getProtocols() {
		return protocols;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((protocols == null) ? 0 : protocols.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Capabilities other = (Capabilities) obj;
		if (protocols == null) {
			if (other.protocols != null)
				return false;
		} else if (!protocols.equals(other.protocols))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return "Capabilities[" + "Protocols=" + protocols + "]";
	}

}
